@@ -10,7 +10,6 @@
 #' Setting the i-th element of the vector to "1" or "-1" means that the model takes into account additional volatility if the returns of the i-th column in the data matrix are either positive or negative.
 #' If "asymmetric = TRUE", the default is set to "rep(-1, N)" i.e. it is assumed that excess volatility occurs for all series if the returns are negative.
 #' @param N Integer specifying the dimension of the BEKK model. Only relevant for \link{bekk_sim}.
-#' @param compare Boolean specifying if the outcome of an asymmetric model is compared to its symmetric estimation result.
 #' @return Returns a S3 class "bekkSpec"  object containing the specifications of the model to be estimated.
 #'
 #'
@@ -18,7 +17,7 @@
 
 
 bekk_spec <- function(model = list(type = "bekk", asymmetric = FALSE),
-                      init_values = NULL, signs = NULL, N = NULL, compare=FALSE) {
+                      init_values = NULL, signs = NULL, N = NULL) {
 
   if(!is.logical(model$asymmetric) || is.null(model$asymmetric)){
     stop('Please specify whether the model to be estimated is asymmetric or not.')
