@@ -5,7 +5,7 @@ test_that("Symmetric BEKK 2-dims works, ts object and QML_t_ratios = FALSE, n.ah
   x2 <- bekk_forecast(x1, n.ahead = 1)
 
   expect_equal(round(as.numeric(x2$volatility_forecast[1]), 2), 0.2)
-  expect_equal(round(as.numeric(x2$volatility_forecast[2]), 2), -0.2)
+  expect_equal(round(as.numeric(x2$volatility_forecast[2]), 2), -0.21)
   expect_equal(round(as.numeric(x2$volatility_forecast[3]), 2), 0.6)
 
   expect_equal(round(sum(x2$H_t_forecast), 2), 0.35)
@@ -19,13 +19,13 @@ test_that("Symmetric BEKK 2-dims works, ts object and QML_t_ratios = FALSE, n.ah
 
   x2 <- bekk_forecast(x1, n.ahead = 5)
 
-  expect_equal(round(sum(x2$volatility_forecast[,1]), 2), 1)
-  expect_equal(round(sum(x2$volatility_forecast[,2]), 2), -0.99)
-  expect_equal(round(sum(x2$volatility_forecast[,3]), 3), 3.055)
+  expect_equal(round(sum(x2$volatility_forecast[,1]), 2), 1.01)
+  expect_equal(round(sum(x2$volatility_forecast[,2]), 2), -1.1)
+  expect_equal(round(sum(x2$volatility_forecast[,3]), 2), 3.05)
 
-  expect_equal(round(sum(x2$H_t_forecast), 2), 1.83)
-  expect_equal(round(sum(x2$volatility_lower_conf_band), 2), 2.98)
-  expect_equal(round(sum(x2$volatility_upper_conf_band), 2), 3.17)
+  expect_equal(round(sum(x2$H_t_forecast), 2), 1.80)
+  expect_equal(round(sum(x2$volatility_lower_conf_band), 2), 2.91)
+  expect_equal(round(sum(x2$volatility_upper_conf_band), 2), 3.11)
 })
 
 #
@@ -71,10 +71,10 @@ test_that("Asymmetric BEKK 2-dims works, ts object and QML_t_ratios = FALSE, n.a
   x2 <- bekk_forecast(x1, n.ahead = 1)
 
   expect_equal(round(as.numeric(x2$volatility_forecast[1]), 2), 0.2)
-  expect_equal(round(as.numeric(x2$volatility_forecast[2]), 2), -0.24)
-  expect_equal(round(as.numeric(x2$volatility_forecast[3]), 2), 0.59)
+  expect_equal(round(as.numeric(x2$volatility_forecast[2]), 2), -0.25)
+  expect_equal(round(as.numeric(x2$volatility_forecast[3]), 2), 0.58)
 
-  expect_equal(round(sum(x2$H_t_forecast), 2), 0.33)
+  expect_equal(round(sum(x2$H_t_forecast), 2), 0.32)
   expect_equal(round(sum(x2$volatility_lower_conf_band), 2), 0.51)
   expect_equal(round(sum(x2$volatility_upper_conf_band), 2), 0.57)
 })
@@ -85,13 +85,13 @@ test_that("Symmetric BEKK 2-dims works, ts object and QML_t_ratios = FALSE, n.ah
 
   x2 <- bekk_forecast(x1, n.ahead = 5)
 
-  expect_equal(round(sum(as.numeric(x2$volatility_forecast[,1])), 2), 1)
-  expect_equal(round(sum(as.numeric(x2$volatility_forecast[,2])), 2), -1.16)
+  expect_equal(round(sum(as.numeric(x2$volatility_forecast[,1])), 2), 1.01)
+  expect_equal(round(sum(as.numeric(x2$volatility_forecast[,2])), 2), -1.30)
   expect_equal(round(sum(as.numeric(x2$volatility_forecast[,3])), 2), 2.85)
 
-  expect_equal(round(sum(x2$H_t_forecast), 2), 1.56)
-  expect_equal(round(sum(x2$volatility_lower_conf_band), 2), 2.57)
-  expect_equal(round(sum(x2$volatility_upper_conf_band), 2), 2.86)
+  expect_equal(round(sum(x2$H_t_forecast), 2), 1.53)
+  expect_equal(round(sum(x2$volatility_lower_conf_band), 2), 2.49)
+  expect_equal(round(sum(x2$volatility_upper_conf_band), 2), 2.78)
 })
 
 #
@@ -141,7 +141,7 @@ test_that("Symmetric scalar BEKK 2-dims works, ts object and QML_t_ratios = FALS
   expect_equal(round(as.numeric(x2$volatility_forecast[2,2]), 2), -0.1)
   expect_equal(round(as.numeric(x2$volatility_forecast[2,3]), 2), 0.64)
 
-  expect_equal(round(sum(x2$H_t_forecast), 2), 4.28)
-  expect_equal(round(sum(x2$volatility_lower_conf_band), 2), 7.38)
-  expect_equal(round(sum(x2$volatility_upper_conf_band), 2), 7.49)
+  expect_equal(round(sum(x2$H_t_forecast), 2), 4.27)
+  expect_equal(round(sum(x2$volatility_lower_conf_band), 2), 7.34)
+  expect_equal(round(sum(x2$volatility_upper_conf_band), 2), 7.46)
 })
